@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "actionmanagerimpl.h"
@@ -260,8 +244,8 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
 
     // toolbar / View
 
-    const MainWidget::ViewMode viewMode = static_cast<MainWidget::ViewMode>(Settings::viewMode());
-    QActionGroup *group = new QActionGroup(this);
+    const auto viewMode = static_cast<MainWidget::ViewMode>(Settings::viewMode());
+    auto *group = new QActionGroup(this);
     action = coll->addAction(QStringLiteral("normal_view"));
     action->setCheckable(true);
     action->setChecked(viewMode == MainWidget::NormalView);
@@ -322,7 +306,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     coll->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_R));
 
     // Settings menu
-    KToggleAction *sqf = coll->add<KToggleAction>(QStringLiteral("show_quick_filter"));
+    auto *sqf = coll->add<KToggleAction>(QStringLiteral("show_quick_filter"));
     sqf->setText(i18n("Show Quick Filter"));
     connect(sqf, &QAction::triggered, d->mainWidget, &MainWidget::slotToggleShowQuickFilter);
     sqf->setChecked(Settings::showQuickFilter());
@@ -368,7 +352,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     connect(action, &QAction::triggered, d->mainWidget, &MainWidget::slotArticleDelete);
     coll->setDefaultShortcut(action, QKeySequence(Qt::Key_Delete));
 
-    KActionMenu *statusMenu = coll->add<KActionMenu>(QStringLiteral("article_set_status"));
+    auto *statusMenu = coll->add<KActionMenu>(QStringLiteral("article_set_status"));
     statusMenu->setText(i18n("&Mark As"));
     statusMenu->setEnabled(false);
 
@@ -396,7 +380,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     connect(action, &QAction::triggered, d->mainWidget, &MainWidget::slotSetSelectedArticleUnread);
     statusMenu->addAction(action);
 
-    KToggleAction *importantAction = coll->add<KToggleAction>(QStringLiteral("article_set_status_important"));
+    auto *importantAction = coll->add<KToggleAction>(QStringLiteral("article_set_status_important"));
     importantAction->setText(i18n("&Mark as Important"));
     importantAction->setIcon(QIcon::fromTheme(QStringLiteral("mail-mark-important")));
     const QList<QKeySequence> importantSC = {QKeySequence(Qt::CTRL + Qt::Key_I), QKeySequence(Qt::Key_I)};
