@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2008 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2008 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "createfoldercommand.h"
@@ -68,7 +52,7 @@ void CreateFolderCommand::Private::doCreate()
         return;
     }
 
-    Folder *parentFolder = qobject_cast<Folder *>(m_selectedSubscription);
+    auto *parentFolder = qobject_cast<Folder *>(m_selectedSubscription);
     if (!parentFolder) {
         parentFolder = m_selectedSubscription ? m_selectedSubscription->parent() : nullptr;
     }
@@ -78,7 +62,7 @@ void CreateFolderCommand::Private::doCreate()
 
     TreeNode *const after = (m_selectedSubscription && m_selectedSubscription->isGroup()) ? m_selectedSubscription : nullptr;
 
-    Folder *const newFolder = new Folder(name);
+    auto *const newFolder = new Folder(name);
     parentFolder->insertChild(newFolder, after);
     m_subscriptionListView->ensureNodeVisible(newFolder);
     q->done();
