@@ -1,26 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-                  2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "feed.h"
@@ -38,10 +22,8 @@
 #include "utils.h"
 #include "feedretriever.h"
 #include "job/downloadfeediconjob.h"
-#include <Syndication/Syndication>
 
 #include "akregator_debug.h"
-#include <QIcon>
 
 #include <QUrl>
 
@@ -376,12 +358,12 @@ void Feed::loadFavicon(const QString &url, bool downloadFavicon)
     if (u.isLocalFile()) {
         setFaviconLocalPath(u.toLocalFile());
     } else {
-        Akregator::DownloadFeedIconJob *job = new Akregator::DownloadFeedIconJob(this);
+        auto *job = new Akregator::DownloadFeedIconJob(this);
         job->setFeedIconUrl(u);
         job->setDownloadFavicon(downloadFavicon);
         connect(job, &DownloadFeedIconJob::result, this, [this](const QString &fileName) {
-                setFaviconLocalPath(fileName);
-                });
+            setFaviconLocalPath(fileName);
+        });
         if (!job->start()) {
             qCWarning(AKREGATOR_LOG) << "Impossible to start DownloadFeedIconJob for url: " << url;
         }
@@ -599,7 +581,7 @@ QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
 
 KJob *Feed::createMarkAsReadJob()
 {
-    ArticleModifyJob *job = new ArticleModifyJob;
+    auto *job = new ArticleModifyJob;
     const auto arts = articles();
     for (const Article &i : arts) {
         const ArticleId aid = { xmlUrl(), i.guid() };
