@@ -1,25 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Sashmit Bhaduri <smt@vfemail.net>
-                  2005 Frank Osterfeld <osterfeld@kde.org>
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    SPDX-FileCopyrightText: 2004 Sashmit Bhaduri <smt@vfemail.net>
+    SPDX-FileCopyrightText: 2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef AKREGATOR_FRAME_H
@@ -60,7 +45,7 @@ public:
     * all tabs but the main tab can be removed.
     * Default is @c true
     */
-    bool isRemovable() const;
+    Q_REQUIRED_RESULT bool isRemovable() const;
 
     /**
      * returns the URL of the embedded part
@@ -134,12 +119,12 @@ protected:
     QIcon m_icon;
     QString m_title;
     QString m_caption;
-    State m_state;
-    int m_progress;
+    State m_state = Idle;
+    int m_progress = -1;
     QString m_statusText;
     QString m_progressId;
     KPIM::ProgressItem *m_progressItem = nullptr;
-    bool m_isRemovable = false;
+    bool m_isRemovable = true;
     bool m_loading = false;
     int m_id;
     static int m_idCounter;
