@@ -1,25 +1,9 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2007 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2007 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "subscriptionlistmodel.h"
@@ -84,7 +68,6 @@ static const Akregator::TreeNode *nodeForIndex(const QModelIndex &index, const F
 
 Akregator::FilterUnreadProxyModel::FilterUnreadProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , m_doFilter(false)
     , m_selectedHierarchy()
 {
     setDynamicSortFilter(true);
@@ -272,7 +255,7 @@ QVariant Akregator::SubscriptionListModel::data(const QModelIndex &index, int ro
         if (!node->isGroup()) {
             return false;
         }
-        const Akregator::Folder *const folder = qobject_cast<const Akregator::Folder *const>(node);
+        const auto *const folder = qobject_cast<const Akregator::Folder *const>(node);
         Q_ASSERT(folder);
         return folder->isOpen();
     }
@@ -436,7 +419,7 @@ void Akregator::FolderExpansionHandler::setExpanded(const QModelIndex &idx, bool
         return;
     }
 
-    Akregator::Folder *const folder = qobject_cast<Akregator::Folder *>(node);
+    auto *const folder = qobject_cast<Akregator::Folder *>(node);
     Q_ASSERT(folder);
     folder->setOpen(expanded);
 }
@@ -478,7 +461,7 @@ QStringList SubscriptionListModel::mimeTypes() const
 
 QMimeData *SubscriptionListModel::mimeData(const QModelIndexList &indexes) const
 {
-    QMimeData *mimeData = new QMimeData;
+    auto *mimeData = new QMimeData;
 
     QList<QUrl> urls;
     for (const QModelIndex &i : indexes) {
@@ -512,7 +495,7 @@ bool SubscriptionListModel::setData(const QModelIndex &idx, const QVariant &valu
     if (!node) {
         return false;
     }
-    RenameSubscriptionJob *job = new RenameSubscriptionJob(this);
+    auto *job = new RenameSubscriptionJob(this);
     job->setSubscriptionId(node->id());
     job->setName(value.toString());
     job->start();
@@ -534,7 +517,7 @@ bool SubscriptionListModel::dropMimeData(const QMimeData *data, Qt::DropAction a
         return false;
     }
 
-    const TreeNode *const droppedOnNode = qobject_cast<const TreeNode *>(nodeForIndex(parent, m_feedList.data()));
+    const auto *const droppedOnNode = qobject_cast<const TreeNode *>(nodeForIndex(parent, m_feedList.data()));
 
     if (!droppedOnNode) {
         return false;
@@ -556,7 +539,7 @@ bool SubscriptionListModel::dropMimeData(const QMimeData *data, Qt::DropAction a
 
     //don't drop nodes into their own subtree
     for (const int id : qAsConst(ids)) {
-        const Folder *const asFolder = qobject_cast<const Folder *>(m_feedList->findByID(id));
+        const auto *const asFolder = qobject_cast<const Folder *>(m_feedList->findByID(id));
         if (asFolder && (asFolder == destFolder || asFolder->subtreeContains(destFolder))) {
             return false;
         }
@@ -569,7 +552,7 @@ bool SubscriptionListModel::dropMimeData(const QMimeData *data, Qt::DropAction a
         if (!node) {
             continue;
         }
-        MoveSubscriptionJob *job = new MoveSubscriptionJob(this);
+        auto *job = new MoveSubscriptionJob(this);
         job->setSubscriptionId(node->id());
         job->setDestination(destFolder->id(), after ? after->id() : -1);
         job->start();
